import 'package:meta/meta.dart';
import 'package:zhiying_base_widget/pages/wechat_teacher_page/model/wechat_teacher_data_model.dart';
import 'package:zhiying_base_widget/pages/wechat_teacher_page/model/wechat_teacher_style_model.dart';

@immutable
abstract class WechatTeacherState {}

class WechatTeacherInitial extends WechatTeacherState {}

/// 数据加载成功
class WechatTeacherLoadedState extends WechatTeacherState {
  WechatTeacherDataModel dataModel;
  WechatTeacherStyleModel styleModel;

  WechatTeacherLoadedState({this.dataModel, this.styleModel});
}

/// 初始化失败
class WechatTeacherInitErrorState extends WechatTeacherState {}

/// 绑定导师成功
class WechatTeacherBindSuccessState extends WechatTeacherState {}

/// 绑定导师失败
class WechatTeacherBindErrorState extends WechatTeacherState {}
